@@ -76,7 +76,7 @@ help_cb (PanelApplet *applet,
       dialog = gtk_message_dialog_new (NULL,
                                        GTK_DIALOG_DESTROY_WITH_PARENT,
                                        GTK_MESSAGE_ERROR,
-                                       GTK_BUTTONS_CLOSE,
+                                       GTK_BUTTONS_OK,
                                        _("There was an error displaying help: %s"),
                                        err->message);
       
