@@ -19,6 +19,7 @@ typedef struct {
 	GtkWidget       *widget;
 
 	GtkWidget       *menu;
+	GtkWidget       *move_item;
 	GList           *user_menu;
 
 	gpointer         data;
@@ -43,22 +44,26 @@ AppletInfo *panel_applet_register    (GtkWidget       *applet,
 				      gpointer         data,
 				      GDestroyNotify   data_destroy,
 				      PanelWidget     *panel,
+				      gboolean         locked,
 				      gint             pos,
 				      gboolean         exactpos,
 				      PanelObjectType  type,
 				      const char      *id);
 
-const char *panel_applet_get_id       (AppletInfo    *info);
-AppletInfo *panel_applet_get_by_id    (const char    *id);
+const char *panel_applet_get_id       (AppletInfo      *info);
+AppletInfo *panel_applet_get_by_id    (const char      *id);
+AppletInfo *panel_applet_get_by_type  (PanelObjectType  object_type);
+
 GSList     *panel_applet_list_applets (void);
 
 void        panel_applet_clean        (AppletInfo    *info);
 
 void panel_applet_queue_applet_to_load (char            *id,
 					PanelObjectType  type,
-					PanelToplevel   *toplevel,
+					char            *toplevel_id,
 					int              position,
-					gboolean         right_stick);
+					gboolean         right_stick,
+					gboolean         locked);
 void panel_applet_load_queued_applets  (void);
 
 
@@ -84,6 +89,8 @@ void        panel_applet_menu_set_recurse (GtkMenu     *menu,
 					   const gchar *key,
 					   gpointer     data);
 
+gboolean    panel_applet_toggle_locked  (AppletInfo *info);
+
 G_END_DECLS
 
 #endif
