@@ -44,7 +44,8 @@ enum {
 	PROP_MENU_PATH,
 	PROP_CUSTOM_ICON,
 	PROP_USE_MENU_PATH,
-	PROP_USE_CUSTOM_ICON
+	PROP_USE_CUSTOM_ICON,
+	PROP_DND_ENABLED
 };
 
 struct _PanelMenuButtonPrivate {
@@ -59,6 +60,7 @@ struct _PanelMenuButtonPrivate {
 
 	guint                  use_menu_path : 1;
 	guint                  use_custom_icon : 1;
+	guint                  dnd_enabled : 1;
 };
 
 static GObjectClass *parent_class;
@@ -67,10 +69,6 @@ static void
 panel_menu_button_instance_init (PanelMenuButton      *button,
 				 PanelMenuButtonClass *klass)
 {
-	static GtkTargetEntry dnd_targets [] = {
-		{ "application/x-panel-applet-internal", 0, 0 }
-	};
-
 	button->priv = g_new0 (PanelMenuButtonPrivate, 1);
 
 	button->priv->info         = NULL;
@@ -85,12 +83,6 @@ panel_menu_button_instance_init (PanelMenuButton      *button,
 
 	button_widget_set_stock_id (BUTTON_WIDGET (button), PANEL_STOCK_GNOME_LOGO);
 
-	GTK_WIDGET_UNSET_FLAGS (button, GTK_NO_WINDOW);
-	gtk_drag_source_set (GTK_WIDGET (button), GDK_BUTTON1_MASK,
-			     dnd_targets, 1,
-			     GDK_ACTION_COPY | GDK_ACTION_MOVE);
-	GTK_WIDGET_SET_FLAGS (button, GTK_NO_WINDOW);
-
 	/* FIXME: set a tooltip */
 }
 
@@ -146,6 +138,9 @@ panel_menu_button_get_property (GObject    *object,
 	case PROP_USE_CUSTOM_ICON:
 		g_value_set_boolean (value, button->priv->use_custom_icon);
 		break;
+	case PROP_DND_ENABLED:
+		g_value_set_boolean (value, button->priv->dnd_enabled);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
@@ -177,6 +172,9 @@ panel_menu_button_set_property (GObject      *object,
 	case PROP_USE_CUSTOM_ICON:
 		panel_menu_button_set_use_custom_icon (button, g_value_get_boolean (value));
 		break;
+	case PROP_DND_ENABLED:
+		panel_menu_button_set_dnd_enabled (button, g_value_get_boolean (value));
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
@@ -211,6 +209,9 @@ panel_menu_button_parent_set (GtkWidget *widget,
 		button->priv->toplevel = NULL;
 
 	panel_menu_button_associate_panel (button);
+
+	if (GTK_WIDGET_CLASS (parent_class)->parent_set)
+		GTK_WIDGET_CLASS (parent_class)->parent_set (widget, previous_parent);
 }
 
 static void
@@ -285,13 +286,15 @@ panel_menu_button_menu_detacher	(GtkWidget *widget,
 	button->priv->menu = NULL;
 }
 
-static void
+void
 panel_menu_button_popup_menu (PanelMenuButton *button,
 			      guint            n_button,
 			      guint32          activate_time)
 {
 	GdkScreen *screen;
 
+	g_return_if_fail (PANEL_IS_MENU_BUTTON (button));
+
 	if (button->priv->menu && menu_need_reread (GTK_WIDGET (button->priv->menu))) {
 		g_object_unref (button->priv->menu);
 		button->priv->menu = NULL;
@@ -449,9 +452,18 @@ panel_menu_button_class_init (PanelMenuButtonClass *klass,
 			PROP_USE_CUSTOM_ICON,
                         g_param_spec_boolean ("use-custom-icon",
 					      _("Use Custom Icon"),
-					     _("Use the icon specified by the custom-icon property"),
-					     FALSE,
-					     G_PARAM_READWRITE));
+					      _("Use the icon specified by the custom-icon property"),
+					      FALSE,
+					      G_PARAM_READWRITE));
+
+	g_object_class_install_property (
+			gobject_class,
+			PROP_DND_ENABLED,
+                        g_param_spec_boolean ("dnd-enabled",
+					      _("Drag N' Drop enabled"),
+					      _("Whether or not drag and drop is enabled on the widget"),
+					      FALSE,
+					      G_PARAM_READWRITE));
 }
 
 GType
@@ -538,6 +550,7 @@ panel_menu_button_load (const char  *menu_path,
 			const char  *custom_icon,
 			gboolean     use_custom_icon,
 			PanelWidget *panel,
+			gboolean     locked,
 			int          position,
 			gboolean     exactpos,
 			const char  *id)
@@ -554,8 +567,9 @@ panel_menu_button_load (const char  *menu_path,
 			       NULL);
 
 	button->priv->info = panel_applet_register (
-					GTK_WIDGET (button), NULL, NULL, panel,
-					position, exactpos, PANEL_OBJECT_MENU, id);
+					GTK_WIDGET (button), NULL, NULL,
+					panel, locked, position, exactpos,
+					PANEL_OBJECT_MENU, id);
 	if (!button->priv->info) {
 		gtk_widget_destroy (GTK_WIDGET (button));
 		return;
@@ -672,6 +686,14 @@ panel_menu_button_set_use_menu_path (PanelMenuButton *button,
 	panel_menu_button_set_icon (button);
 }
 
+gboolean
+panel_menu_button_get_use_menu_path (PanelMenuButton *button)
+{
+	g_return_val_if_fail (PANEL_IS_MENU_BUTTON (button), FALSE);
+
+	return button->priv->use_menu_path;
+}
+
 void
 panel_menu_button_set_use_custom_icon (PanelMenuButton *button,
 				       gboolean         use_custom_icon)
@@ -685,6 +707,7 @@ panel_menu_button_set_use_custom_icon (PanelMenuButton *button,
 
 void
 panel_menu_button_load_from_gconf (PanelWidget *panel,
+				   gboolean     locked,
 				   int          position,
 				   gboolean     exactpos,
 				   const char  *id)
@@ -720,6 +743,7 @@ panel_menu_button_load_from_gconf (PanelWidget *panel,
 				custom_icon,
 				use_custom_icon,
 				panel,
+				locked,
 				position,
 				exactpos,
 				id);
@@ -781,3 +805,30 @@ panel_menu_button_change_orientation (PanelMenuButton  *button,
 
 	button_widget_set_params (BUTTON_WIDGET (button), TRUE, orientation);
 }
+
+void
+panel_menu_button_set_dnd_enabled (PanelMenuButton *button,
+				   gboolean         dnd_enabled)
+{
+	g_return_if_fail (PANEL_IS_MENU_BUTTON (button));
+
+	dnd_enabled = dnd_enabled != FALSE;
+
+	if (button->priv->dnd_enabled == dnd_enabled)
+		return;
+
+	if (dnd_enabled) {
+		static GtkTargetEntry dnd_targets [] = {
+			{ "application/x-panel-applet-internal", 0, 0 }
+		};
+
+		GTK_WIDGET_UNSET_FLAGS (button, GTK_NO_WINDOW);
+		gtk_drag_source_set (GTK_WIDGET (button), GDK_BUTTON1_MASK,
+				     dnd_targets, 1,
+				     GDK_ACTION_COPY | GDK_ACTION_MOVE);
+		gtk_drag_source_set_icon_stock (GTK_WIDGET (button),
+						PANEL_STOCK_GNOME_LOGO);
+		GTK_WIDGET_SET_FLAGS (button, GTK_NO_WINDOW);
+	} else
+		gtk_drag_source_unset (GTK_WIDGET (button));
+}
