@@ -280,14 +280,17 @@ get_encoding_from_locale (const char *locale)
 static const char *
 get_encoding (int encoding, const char *lang)
 {
-	const char *enc = strchr (lang, '.');
+	const char *enc = NULL;
+	if (lang != NULL)
+		enc = strchr (lang, '.');
 	if (enc != NULL) {
 		enc++;
 		if (strcmp (enc, "UTF-8") == 0)
 			return NULL;
 		return enc;
 	} else if (encoding == ENCODING_LEGACY_MIXED) {
-		return get_encoding_from_locale (lang);
+		enc = get_encoding_from_locale (lang);
+		return enc;
 	} else {
 		/* no decoding */
 		return NULL;
@@ -447,12 +450,6 @@ quick_desktop_item_load_uri (const char *uri,
 		retval = NULL;
 	}
 
-	/* Failsafe */
-	if (!name_lang)
-		name_lang = g_strdup (setlocale (LC_CTYPE, NULL));
-	if (!comment_lang)
-		comment_lang = g_strdup (setlocale (LC_CTYPE, NULL));
-
 	/* Convert encodings */
 
 	/* Make sure we have some encoding type */
@@ -473,6 +470,16 @@ quick_desktop_item_load_uri (const char *uri,
 			char *utf8_string = g_convert (retval->name, -1,
 						       "UTF-8", enc,
 						       NULL, NULL, NULL);
+			/* Fallback, if we can't convert from the
+			 * encoding we have gotten, just try on a hunch
+			 * the current locale.  It's better then passing a
+			 * non-utf-8 string */
+			if (utf8_string == NULL) {
+				g_get_charset (&enc);
+				utf8_string = g_convert (retval->name, -1,
+							 "UTF-8", enc,
+							 NULL, NULL, NULL);
+			}
 			if (utf8_string != NULL) {
 				g_free (retval->name);
 				retval->name = utf8_string;
@@ -488,6 +495,16 @@ quick_desktop_item_load_uri (const char *uri,
 			char *utf8_string = g_convert (retval->comment, -1,
 						       "UTF-8", enc,
 						       NULL, NULL, NULL);
+			/* Fallback, if we can't convert from the
+			 * encoding we have gotten, just try on a hunch
+			 * the current locale.  It's better then passing a
+			 * non-utf-8 string */
+			if (utf8_string == NULL) {
+				g_get_charset (&enc);
+				utf8_string = g_convert (retval->comment, -1,
+							 "UTF-8", enc,
+							 NULL, NULL, NULL);
+			}
 			if (utf8_string != NULL) {
 				g_free (retval->comment);
 				retval->comment = utf8_string;
